# encoding: utf-8

#--
# Copyright DataStax, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#++

module Cassandra
  module Protocol
    class FunctionFailureErrorResponse < ErrorResponse
      attr_reader :keyspace, :name, :signature

      def initialize(custom_payload, warnings, code, message, keyspace, name, signature)
        super(custom_payload, warnings, code, message)

        @keyspace  = keyspace
        @name      = name
        @signature = signature
      end

      def to_error(keyspace, statement, options, hosts, consistency, retries)
        Errors::FunctionCallError.new(@message,
                                      @custom_payload,
                                      @warnings,
                                      keyspace,
                                      statement,
                                      options,
                                      hosts,
                                      consistency,
                                      retries,
                                      @keyspace,
                                      @name,
                                      @signature)
      end

      def to_s
        "#{super} #{@keyspace} #{@name} #{@signature}"
      end
    end
  end
end
